elephant.test.test_spectral module — Elephant 0.5.0 documentation

# elephant.test.test_spectral module

Unit tests for the spectral module.

class `elephant.test.test_spectral.` `WelchCohereTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `test_welch_cohere_behavior`()
  `test_welch_cohere_errors`()
  `test_welch_cohere_input_types`()
  `test_welch_cohere_multidim_input`()

class `elephant.test.test_spectral.` `WelchPSDTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `test_welch_psd_behavior`()
  `test_welch_psd_errors`()
  `test_welch_psd_input_types`()
  `test_welch_psd_multidim_input`()

`elephant.test.test_spectral.` `suite`()